//-*-c++-*-
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "tulip/Metric.h"
#include "tulip/SuperGraph.h"
#include "tulip/MetricProxy.h"

Metric::Metric (const PropertyContext &context):Property<DoubleType , DoubleType>(context) {
  metricProxy=(MetricProxy *)context.propertyProxy;
}

